@@ -20,3 +20,10 @@ async def create_trade_transform(trade_transform: TradeTransform):
     trade_transform_repository = ItemHolder.get_entity(TradeTransformRepository)
     trade_transform_repository.append(trade_transform)
     return trade_transform
+
+
+@router.delete('/transform/trade')
+async def delete_trade_transform(trade_transform: TradeTransform):
+    trade_transform_repository = ItemHolder.get_entity(TradeTransformRepository)
+    trade_transform_repository.remove(trade_transform)
+    return trade_transform
